@@ -444,11 +444,10 @@ class S3Client {
     }
 
     private function initiateMultipartUpload($bucket, $key) {
-        $url = $this->buildUrl($bucket, $key) . '?uploads';
+        $url = $this->buildUrl($bucket, $key) . '?uploads=';
         // Use empty payload hash for multipart initiate (required by AWS spec)
         $emptyPayloadHash = 'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855';
-        // Don't send Content-Type or Content-Length for initiate - R2 might not like them
-        $headers = $this->buildHeadersMinimal('POST', $bucket, $key, 'uploads', $emptyPayloadHash);
+        $headers = $this->buildHeaders('POST', $bucket, $key, 'uploads=', 'application/octet-stream', $emptyPayloadHash, 0);
 
         // Log the exact URL and headers for debugging
         error_log("Multipart initiate URL: {$url}");
@@ -457,7 +456,6 @@ class S3Client {
         $ch = curl_init();
         curl_setopt($ch, CURLOPT_URL, $url);
         curl_setopt($ch, CURLOPT_POST, true);
-        curl_setopt($ch, CURLOPT_POSTFIELDS, ''); // Explicitly set empty body
         curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
         curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
         curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 30);
