@@ -34,11 +34,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST' && !$is_delegated_user) {
                     'can_manage_wordpress' => isset($_POST['can_manage_wordpress']),
                 ];
                 
-                // Handle allowed domains
-                if (!empty($_POST['allowed_domains'])) {
-                    $domains = array_map('trim', explode(',', $_POST['allowed_domains']));
-                    $data['allowed_domains'] = array_filter($domains);
-                }
                 
                 $result = $delegatedUserManager->createDelegatedUser($data, $current_user);
                 
@@ -67,15 +62,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST' && !$is_delegated_user) {
                     'is_active' => isset($_POST['is_active']),
                 ];
                 
-                // Handle allowed domains
-                if (isset($_POST['allowed_domains'])) {
-                    if (empty($_POST['allowed_domains'])) {
-                        $data['allowed_domains'] = null;
-                    } else {
-                        $domains = array_map('trim', explode(',', $_POST['allowed_domains']));
-                        $data['allowed_domains'] = array_filter($domains);
-                    }
-                }
                 
                 $result = $delegatedUserManager->updateDelegatedUser($user_id, $data, $current_user);
                 
@@ -187,6 +173,11 @@ if ($is_root) {
     color: #1976d2;
     padding: 3px 8px;
     border-radius: 12px;
+}
+
+.form-text {
+    color: #ffffff !important;
+    opacity: 0.9;
     font-size: 0.75rem;
 }
 </style>
@@ -344,15 +335,6 @@ if ($is_root) {
                                 </div>
                             </div>
                             
-                            <div class="row">
-                                <div class="col-md-12">
-                                    <div class="mb-3">
-                                        <label for="allowed_domains" class="form-label">Specific Domain Access (Optional)</label>
-                                        <input type="text" class="form-control" id="allowed_domains" name="allowed_domains" placeholder="example.com, subdomain.example.com">
-                                        <div class="form-text">Restrict access to specific domains only. Leave empty to allow access to all parent account domains based on permissions.</div>
-                                    </div>
-                                </div>
-                            </div>
                         </div>
                     </div>
                     
@@ -552,11 +534,6 @@ if ($is_root) {
                         </div>
                     </div>
                     
-                    <div class="mb-3">
-                        <label for="edit_allowed_domains" class="form-label">Specific Domain Access (Optional)</label>
-                        <input type="text" class="form-control" id="edit_allowed_domains" name="allowed_domains" placeholder="example.com, subdomain.example.com">
-                        <div class="form-text">Restrict access to specific domains only. Leave empty to allow access to all parent account domains based on permissions.</div>
-                    </div>
                 </div>
                 <div class="modal-footer">
                     <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
@@ -616,13 +593,6 @@ function editUser(userId) {
     document.getElementById('edit_can_view_terminal').checked = user.can_view_terminal == 1;
     document.getElementById('edit_can_manage_wordpress').checked = user.can_manage_wordpress == 1;
     
-    // Set allowed domains
-    if (user.allowed_domains) {
-        const domains = JSON.parse(user.allowed_domains);
-        document.getElementById('edit_allowed_domains').value = domains.join(', ');
-    } else {
-        document.getElementById('edit_allowed_domains').value = '';
-    }
     
     // Show modal
     new bootstrap.Modal(document.getElementById('editUserModal')).show();
